# from django.contrib.gis.db import models as gis_models
from django.db import models

from .abstract import (
    AbstractUniqueIdentifier,
    AbstractEditableResource,
    AbstractDescriptableResource,
    AlternativeURNs,
    AbstractUniqueIdentifier
)


class City(
    AbstractUniqueIdentifier,
    AbstractEditableResource,
    AbstractDescriptableResource,
    AlternativeURNs,
    models.Model,
):
    """City model

    A city has names.
    The location is stored using GIS extensions.

    """

    names = models.ManyToManyField(
        "meleager.Name",
        related_name="cities",
        help_text="The multilingual names for this object.",
    )

    # location = gis_models.PointField(null=True)
    longitude = models.DecimalField(max_digits=9, decimal_places=5, null=True, blank=True, default=None)
    latitude = models.DecimalField(max_digits=9, decimal_places=5, null=True, blank=True, default=None)

    def __str__(self):
        return self.names.first().name

    class Meta:
        verbose_name_plural = "cities"
