from django.db import models

from .abstract import AbstractEditableResource, AbstractUniqueIdentifier


class KeywordCategory(AbstractEditableResource, AbstractUniqueIdentifier, models.Model):
    names = models.ManyToManyField(
        "meleager.Name",
        related_name="keyword_categories",
        help_text="The multilingual names for this object.",
    )

    def __str__(self):
        if self.names.first():
            return f"{self.names.first().name} ({self.pk})"
        else:
            return f"Category PK {self.pk}"

    class Meta:
        verbose_name_plural = "Keyword categories"


class Keyword(AbstractEditableResource, AbstractUniqueIdentifier, models.Model):
    names = models.ManyToManyField(
        "meleager.Name",
        related_name="keywords",
        help_text="The multilingual names for this object.",
    )

    category = models.ForeignKey(
        KeywordCategory,
        on_delete=models.SET_NULL,
        related_name="keywords",
        help_text="The category this keyword belongs to.",
        null=True,
    )

    def __str__(self):
        if self.names.first():
            return f"{self.names.first().name} ({self.pk})"
        else:
            return f"Keyword PK {self.pk}"
