from meleager.models import Author, Name, Passage
from django.test import TestCase

class PassageAuthorFormsTest(TestCase):
    fixtures = ["test_data.json"]

    @classmethod
    def setUpTestData(cls):
        # Create new author
        cls.new_author = Author.objects.create()
        cls.new_author.names.add(Name.objects.create(name="test_regular_user_post_author_passage_form", language_id="eng"))
        cls.passage = Passage.objects.first()
        cls.passage_url = f"{cls.passage.get_absolute_url()}#authors"

    def test_anonymous_user_add_form_redirect(self):
        resp = self.client.post(f'/authors/passage/{self.passage.pk}/create/')
        self.assertRedirects(resp, f'/auth/login/?next=/authors/passage/{self.passage.pk}/create/')

    def test_regular_user_post_author_passage_form(self):
        self.client.login(username="editor", password="editor")

        resp = self.client.post(f'/authors/passage/{self.passage.pk}/create/', {"author": self.new_author.pk})
        self.assertRedirects(resp, self.passage_url)

        self.assertEquals(self.passage.authors.count(), 2)
        self.assertIn(self.new_author, self.passage.authors.all())

    def test_anonymous_user_delete_form_redirect(self):
        self.passage.authors.add(self.new_author)
        resp = self.client.post(f'/authors/passage/{self.passage.pk}/delete/{self.new_author.pk}/')
        self.assertRedirects(resp, f'/auth/login/?next=/authors/passage/{self.passage.pk}/delete/{self.new_author.pk}/')

    def test_editor_delete_author_passage_form(self):
        self.client.login(username="editor", password="editor")

        self.passage.authors.add(self.new_author)

        resp = self.client.post(f'/authors/passage/{self.passage.pk}/delete/{self.new_author.pk}/')
        self.assertRedirects(resp, self.passage_url)
        self.assertEquals(self.passage.authors.count(), 1)
