from django.test import TestCase
from django.urls import reverse
from meleager.models import Book, Author, Name, Passage


class PassageAuthorsTest(TestCase):
    fixtures = ["test_data.json"]

    @classmethod
    def setUpTestData(cls):
        book = Book.objects.first()
        cls.passage = Passage.objects.get(book=book, fragment=12)
        cls.passage.authors.clear()  # Remove existing authors from fixtures.
        name = Name.objects.create(name="Name", language_id="fra")
        cls.author = Author.objects.create()
        cls.author.names.add(name)

    def setUp(self):
        self.client.login(username="editor", password="editor")

    def test_create_author_form(self):
        response = self.client.get(
            reverse("web:passage-author-create", args=(self.passage.pk,))
        )
        self.assertEquals(response.status_code, 200)

    def test_create_author(self):
        self.assertEquals(self.passage.authors.count(), 0)

        self.client.post(
            reverse("web:passage-author-create", args=(self.passage.pk,)),
            data={
                "author": self.author.pk,
            },
        )

        self.assertEquals(self.passage.authors.count(), 1)

    def test_delete_author_form(self):
        self.passage.authors.add(self.author)

        response = self.client.get(
            reverse(
                "web:passage-author-delete",
                kwargs={"author_pk": self.author.pk, "passage_pk": self.passage.pk},
            ),
        )
        self.assertEquals(response.status_code, 200)

    def test_delete_author(self):
        self.passage.authors.add(self.author)
        self.assertEquals(self.passage.authors.count(), 1)

        self.client.post(
            reverse(
                "web:passage-author-delete",
                kwargs={"author_pk": self.author.pk, "passage_pk": self.passage.pk},
            ),
        )

        self.assertEquals(self.passage.authors.count(), 0)
