from django.test import TestCase
from django.urls import reverse
from meleager.models import Book, Description, Passage


class PassageDescriptionsTest(TestCase):
    fixtures = ["test_data.json"]

    @classmethod
    def setUpTestData(cls):
        book = Book.objects.first()
        cls.passage = Passage.objects.get(book=book, fragment=12)
        cls.passage.descriptions.clear()

    def setUp(self):
        self.client.login(username="editor", password="editor")

    def test_create_description_form(self):
        response = self.client.get(
            reverse("web:passage-description-create", args=(self.passage.pk,))
        )
        self.assertEquals(response.status_code, 200)

    def test_create_description(self):
        self.assertEquals(self.passage.descriptions.count(), 0)

        self.client.post(
            reverse("web:passage-description-create", args=(self.passage.pk,)),
            data={
                "description": "description",
                "language": "fra",
            },
        )

        first_description = self.passage.descriptions.first()
        self.assertEquals(first_description.description, "description")
        self.assertEquals(first_description.language.code, "fra")

    def test_update_description_form(self):
        description = Description.objects.create(
            description="old_content", language_id="eng"
        )
        self.passage.descriptions.add(description)

        response = self.client.get(
            reverse(
                "web:passage-description-update",
                kwargs={
                    "description_pk": description.pk,
                    "passage_pk": self.passage.pk,
                },
            )
        )
        self.assertEquals(response.status_code, 200)

    def test_update_description(self):
        description = Description.objects.create(
            description="old_content", language_id="eng"
        )
        self.passage.descriptions.add(description)
        old_first_description = self.passage.descriptions.first()
        self.assertEquals(old_first_description.description, "old_content")
        self.assertEquals(old_first_description.language.code, "eng")

        self.client.post(
            reverse(
                "web:passage-description-update",
                kwargs={
                    "description_pk": description.pk,
                    "passage_pk": self.passage.pk,
                },
            ),
            data={
                "description": "new_content",
                "language": "spa",
            },
        )

        new_first_description = self.passage.descriptions.first()
        self.assertEquals(new_first_description.description, "new_content")
        self.assertEquals(new_first_description.language.code, "spa")

    def test_delete_description_form(self):
        description = Description.objects.create(
            description="old_content", language_id="eng"
        )
        self.passage.descriptions.add(description)

        response = self.client.get(
            reverse(
                "web:passage-description-delete",
                kwargs={
                    "description_pk": description.pk,
                    "passage_pk": self.passage.pk,
                },
            ),
        )
        self.assertEquals(response.status_code, 200)

    def test_delete_description(self):
        description = Description.objects.create(
            description="description", language_id="eng"
        )
        self.passage.descriptions.add(description)
        self.assertEquals(self.passage.descriptions.count(), 1)

        self.client.post(
            reverse(
                "web:passage-description-delete",
                kwargs={
                    "description_pk": description.pk,
                    "passage_pk": self.passage.pk,
                },
            ),
            data={
                "pk": description.pk,
            },
        )

        self.assertEquals(self.passage.descriptions.count(), 0)
