from django.test import TestCase
from django.urls import reverse
from meleager.models import Book, Keyword, Name, Passage


class PassageKeywordsTest(TestCase):
    fixtures = ["test_data.json"]

    @classmethod
    def setUpTestData(cls):
        book = Book.objects.first()
        cls.passage = Passage.objects.get(book=book, fragment=12)
        cls.passage.keywords.clear()  # Remove existing keywords from fixtures.
        name = Name.objects.create(name="Name", language_id="fra")
        cls.keyword = Keyword.objects.create()
        cls.keyword.names.add(name)

    def setUp(self):
        self.client.login(username="editor", password="editor")

    def test_create_keyword_form(self):
        response = self.client.get(
            reverse("web:passage-keyword-create", args=(self.passage.pk,))
        )
        self.assertEquals(response.status_code, 200)

    def test_create_keyword(self):
        self.assertEquals(self.passage.keywords.count(), 0)

        self.client.post(
            reverse("web:passage-keyword-create", args=(self.passage.pk,)),
            data={
                "keyword": self.keyword.pk,
            },
        )

        self.assertEquals(self.passage.keywords.count(), 1)

    def test_delete_keyword_form(self):
        self.passage.keywords.add(self.keyword)

        response = self.client.get(
            reverse(
                "web:passage-keyword-delete",
                kwargs={"keyword_pk": self.keyword.pk, "passage_pk": self.passage.pk},
            ),
        )
        self.assertEquals(response.status_code, 200)

    def test_delete_keyword(self):
        self.passage.keywords.add(self.keyword)
        self.assertEquals(self.passage.keywords.count(), 1)

        self.client.post(
            reverse(
                "web:passage-keyword-delete",
                kwargs={"keyword_pk": self.keyword.pk, "passage_pk": self.passage.pk},
            ),
        )

        self.assertEquals(self.passage.keywords.count(), 0)
