from django.test import TestCase
from django.urls import reverse

from meleager.models import Book, Passage


class PassageTextsTest(TestCase):
    fixtures = ["test_data.json"]

    @classmethod
    def setUpTestData(cls):
        book = Book.objects.first()
        cls.passage = Passage.objects.get(book=book, fragment=12)
        cls.passage.texts.clear()  # Remove existing manuscripts from fixtures.

    def setUp(self):
        self.client.login(username="editor", password="editor")

    def test_create_text_form(self):
        response = self.client.get(
            reverse("web:passage-text-create", args=(self.passage.pk,))
        )
        self.assertEquals(response.status_code, 200)

    def test_create_text(self):
        self.assertEquals(self.passage.texts.count(), 0)

        self.client.post(
            reverse("web:passage-text-create", args=(self.passage.pk,)),
            data={"text": "Text", "language": "eng"},
        )

        first_text = self.passage.texts.first()
        self.assertEquals(first_text.language.code, "eng")
        self.assertEquals(first_text.text, "Text")
