from django.test import TestCase
from django.urls import reverse
from meleager.models import Book, Passage


class ScholiumTest(TestCase):
    fixtures = ["test_data.json"]

    @classmethod
    def setUpTestData(cls):
        book = Book.objects.first()
        cls.passage = Passage.objects.get(book=book, fragment=12)

    def setUp(self):
        self.client.login(username="editor", password="editor")

    def test_detail_page_ok(self):
        resp = self.client.get(
            "/passages/urn:cts:greekLit:tlg5011.tlg001.sag:42.12.666/"
        )
        self.assertEqual(resp.status_code, 200)
        # self.assertContains(resp, "42.12.666")

    def test_passage_link_to_scholium(self):
        resp = self.client.get("/passages/urn:cts:greekLit:tlg7000.tlg001.ag:42.12/")
        self.assertEqual(resp.status_code, 200)
        self.assertContains(
            resp, "/passages/urn:cts:greekLit:tlg5011.tlg001.sag:42.12.666/"
        )

    def test_display_scholium_form(self):
        response = self.client.get(
            reverse("web:scholium-create", args=(self.passage.pk,))
        )
        self.assertEquals(response.status_code, 200)

    def test_create_scholium(self):
        self.passage.scholia.clear()
        self.assertEquals(self.passage.scholia.count(), 0)

        self.client.post(
            reverse("web:scholium-create", args=(self.passage.pk,)),
            data={
                "number": "667",
            },
        )

        first_scholium = self.passage.scholia.first()
        self.assertEquals(first_scholium.number, 667)
        self.assertEquals(first_scholium.passage.fragment, self.passage.fragment)
