from django.test import TestCase
from django.urls import reverse
from meleager.models import Book, City, Name, Passage


class ScholiumCitiesTest(TestCase):
    fixtures = ["test_data.json"]

    @classmethod
    def setUpTestData(cls):
        book = Book.objects.first()
        cls.passage = Passage.objects.get(book=book, fragment=12)
        cls.scholium = cls.passage.scholia.first()
        cls.scholium.cities.clear()  # Remove existing cities from fixtures.
        name = Name.objects.create(name="Name", language_id="fra")
        cls.city = City.objects.create()
        cls.city.names.add(name)

    def setUp(self):
        self.client.login(username="editor", password="editor")

    def test_create_city_form(self):
        response = self.client.get(
            reverse("web:scholium-city-create", args=(self.scholium.pk,))
        )
        self.assertEquals(response.status_code, 200)

    def test_create_city(self):
        self.assertEquals(self.scholium.cities.count(), 0)

        self.client.post(
            reverse("web:scholium-city-create", args=(self.scholium.pk,)),
            data={
                "city": self.city.pk,
            },
        )

        self.assertEquals(self.scholium.cities.count(), 1)

    def test_delete_city_form(self):
        self.scholium.cities.add(self.city)

        response = self.client.get(
            reverse(
                "web:scholium-city-delete",
                kwargs={"city_pk": self.city.pk, "scholium_pk": self.scholium.pk},
            ),
        )
        self.assertEquals(response.status_code, 200)

    def test_delete_city(self):
        self.scholium.cities.add(self.city)
        self.assertEquals(self.scholium.cities.count(), 1)

        self.client.post(
            reverse(
                "web:scholium-city-delete",
                kwargs={"city_pk": self.city.pk, "scholium_pk": self.scholium.pk},
            ),
        )

        self.assertEquals(self.scholium.cities.count(), 0)
