from django.test import TestCase
from django.urls import reverse
from meleager.models import Book, Keyword, Name, Passage


class ScholiumKeywordsTest(TestCase):
    fixtures = ["test_data.json"]

    @classmethod
    def setUpTestData(cls):
        book = Book.objects.first()
        cls.passage = Passage.objects.get(book=book, fragment=12)
        cls.scholium = cls.passage.scholia.first()
        cls.scholium.keywords.clear()  # Remove existing keywords from fixtures.
        name = Name.objects.create(name="Name", language_id="fra")
        cls.keyword = Keyword.objects.create()
        cls.keyword.names.add(name)

    def setUp(self):
        self.client.login(username="editor", password="editor")

    def test_create_keyword_form(self):
        response = self.client.get(
            reverse("web:scholium-keyword-create", args=(self.scholium.pk,))
        )
        self.assertEquals(response.status_code, 200)

    def test_create_keyword(self):
        self.assertEquals(self.scholium.keywords.count(), 0)

        self.client.post(
            reverse("web:scholium-keyword-create", args=(self.scholium.pk,)),
            data={
                "keyword": self.keyword.pk,
            },
        )

        self.assertEquals(self.scholium.keywords.count(), 1)

    def test_delete_keyword_form(self):
        self.scholium.keywords.add(self.keyword)

        response = self.client.get(
            reverse(
                "web:scholium-keyword-delete",
                kwargs={"keyword_pk": self.keyword.pk, "scholium_pk": self.scholium.pk},
            ),
        )
        self.assertEquals(response.status_code, 200)

    def test_delete_keyword(self):
        self.scholium.keywords.add(self.keyword)
        self.assertEquals(self.scholium.keywords.count(), 1)

        self.client.post(
            reverse(
                "web:scholium-keyword-delete",
                kwargs={"keyword_pk": self.keyword.pk, "scholium_pk": self.scholium.pk},
            ),
        )

        self.assertEquals(self.scholium.keywords.count(), 0)
