from django.test import TestCase
from django.urls import reverse

from meleager.models import Book, Passage


class ScholiumManuscriptsTest(TestCase):
    fixtures = ["test_data.json"]

    @classmethod
    def setUpTestData(cls):
        book = Book.objects.first()
        cls.passage = Passage.objects.get(book=book, fragment=12)
        cls.scholium = cls.passage.scholia.first()
        cls.scholium.manuscripts.clear()

    def setUp(self):
        self.client.login(username="editor", password="editor")

    def test_create_manuscript_form(self):
        response = self.client.get(
            reverse("web:scholium-manuscript-create", args=(self.scholium.pk,))
        )
        self.assertEquals(response.status_code, 200)

    def test_create_manuscript(self):
        self.assertEquals(self.scholium.manuscripts.count(), 0)

        self.client.post(
            reverse("web:scholium-manuscript-create", args=(self.scholium.pk,)),
            data={
                "title": "title",
                "url": "https://digi.ub.uni-heidelberg.de/iiif/2/cpgraec23:049.jpg/pct:71.94367850809665,13.06538505399276,15.729793177496104,4.061230865354575/full/0/default.jpg",
            },
        )

        first_manuscript = self.scholium.manuscripts.first()
        self.assertEquals(first_manuscript.title, "title")
        self.assertEquals(
            first_manuscript.url,
            "https://digi.ub.uni-heidelberg.de/iiif/2/cpgraec23:049.jpg/pct:71.94367850809665,13.06538505399276,15.729793177496104,4.061230865354575/full/0/default.jpg",
        )
