from itertools import chain
from django.shortcuts import get_object_or_404
from django.views import generic
from meleager.models import Language, Passage


class PassageDetail(generic.DetailView):
    model = Passage
    template_name = "web/passage/passage.html"
    context_object_name = "passage"

    def get_queryset(self):
        return Passage.objects.prefetch_related(
            "authors", "authors__names", "comments", "comments__descriptions"
        )

    def get_object(self):
        obj = get_object_or_404(
            self.get_queryset(),
            book__number=self.kwargs.get("book"),
            fragment=self.kwargs.get("fragment"),
            sub_fragment=self.kwargs.get("sub_fragment", ""),
        )
        return obj

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        passage = self.get_object()
        context["page_title"] = str(passage)
        context["texts"] = list(
            chain(
                passage.texts.filter(language__code="grc"),
                passage.texts.exclude(language__code="grc"),
            )
        )
        keywords = passage.keywords.all()
        context["keywords"] = keywords
        context["keywords_categories"] = {keyword.category for keyword in keywords}

        return context
